package com.huiju.estateagents.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaSalesBatch;
import com.huiju.estateagents.mapper.TaSalesBatchMapper;
import com.huiju.estateagents.service.ITaSalesBatchService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 销售批次表  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@Service
public class TaSalesBatchServiceImpl extends ServiceImpl<TaSalesBatchMapper, TaSalesBatch> implements ITaSalesBatchService {

    private Logger logger = LoggerFactory.getLogger(TaSalesBatchServiceImpl.class);

    @Autowired
    private TaSalesBatchMapper taSalesBatchMapper;

    @Override
    public IPage<TaSalesBatch> selectByCondition(IPage<TaSalesBatch> page, String salesBatchName, String buildingId, Integer status, Integer orgId) {
        return taSalesBatchMapper.selectByCondition(page, salesBatchName, buildingId, status, orgId);
    }

    @Override
    public ResponseBean delSalesBatchList(Integer orgId, List<TaSalesBatch> taSalesBatchList) {
        ResponseBean responseBean = new ResponseBean();
        Integer count = taSalesBatchMapper.countPreSelectRecord(orgId, taSalesBatchList);
        if (count > 0) {
            responseBean.addError("已有用户预选，请先删除预选记录。");
            return responseBean;
        }
        taSalesBatchMapper.updateSalesBatchStatus(orgId, taSalesBatchList);
        return responseBean;
    }

    /**
     * 获取通知信息
     *
     * @param salesBatchId 销售批次ID
     * @return
     */
    @Override
    public ResponseBean getNoticeInfo(Integer salesBatchId) {
        logger.info("getNoticeInfo 接收参数：saleBatchId：{}", salesBatchId);

        ResponseBean responseBean = new ResponseBean();

        TaSalesBatch salesBatch = getById(salesBatchId);
        if (salesBatch == null) {
            responseBean.addError("未查询到数据");
            return responseBean;
        }

        Long totalHouses = null;
        Long totalRealHeat = null;

        // 获取房源预选数量
        Map<String, Long> result = taSalesBatchMapper.getTotalHousesAndHeat(salesBatchId);
        if (result != null) {
            totalHouses = result.get("totalHouses");
            totalRealHeat = result.get("totalRealHeat");
        }

        JSONObject obj = new JSONObject();
        obj.put("preselectionStartTime", salesBatch.getPreselectionStartTime());
        obj.put("preselectionEndTime", salesBatch.getPreselectionEndTime());
        obj.put("salesNumber", totalHouses == null ? 0 : totalHouses);
        obj.put("preselectionNumber", totalRealHeat == null ? 0 : totalRealHeat);
        responseBean.addSuccess(obj);
        return responseBean;
    }
}
